"""
To run the tests first put yourself into the petitRADTRANS root package directory,
then run the development install command:
    ```
    pip install -e .
    ```
Then simply use the `tox` command:
    ```
    tox
    ```
"""
# TODO test re-binning
